/* autogenerated from ./opcodes_ddfdcb.dat, do not edit */

/*LD B,RLC (IY+$)*/
static void op_FDCB_0x00(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RLC(temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,RLC (IY+$)*/
static void op_FDCB_0x01(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RLC(temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,RLC (IY+$)*/
static void op_FDCB_0x02(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RLC(temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,RLC (IY+$)*/
static void op_FDCB_0x03(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RLC(temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,RLC (IY+$)*/
static void op_FDCB_0x04(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RLC(temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,RLC (IY+$)*/
static void op_FDCB_0x05(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RLC(temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*RLC (IY+$)*/
static void op_FDCB_0x06(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RLC(temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,RLC (IY+$)*/
static void op_FDCB_0x07(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RLC(temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,RRC (IY+$)*/
static void op_FDCB_0x08(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RRC(temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,RRC (IY+$)*/
static void op_FDCB_0x09(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RRC(temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,RRC (IY+$)*/
static void op_FDCB_0x0a(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RRC(temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,RRC (IY+$)*/
static void op_FDCB_0x0b(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RRC(temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,RRC (IY+$)*/
static void op_FDCB_0x0c(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RRC(temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,RRC (IY+$)*/
static void op_FDCB_0x0d(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RRC(temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*RRC (IY+$)*/
static void op_FDCB_0x0e(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RRC(temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,RRC (IY+$)*/
static void op_FDCB_0x0f(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RRC(temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,RL (IY+$)*/
static void op_FDCB_0x10(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RL(temp_byte);
	LD16(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,RL (IY+$)*/
static void op_FDCB_0x11(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RL(temp_byte);
	LD16(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,RL (IY+$)*/
static void op_FDCB_0x12(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RL(temp_byte);
	LD16(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,RL (IY+$)*/
static void op_FDCB_0x13(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RL(temp_byte);
	LD16(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,RL (IY+$)*/
static void op_FDCB_0x14(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RL(temp_byte);
	LD16(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,RL (IY+$)*/
static void op_FDCB_0x15(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RL(temp_byte);
	LD16(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*RL (IY+$)*/
static void op_FDCB_0x16(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RL(temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,RL (IY+$)*/
static void op_FDCB_0x17(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RL(temp_byte);
	LD16(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,RR (IY+$)*/
static void op_FDCB_0x18(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RR(temp_byte);
	LD16(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,RR (IY+$)*/
static void op_FDCB_0x19(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RR(temp_byte);
	LD16(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,RR (IY+$)*/
static void op_FDCB_0x1a(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RR(temp_byte);
	LD16(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,RR (IY+$)*/
static void op_FDCB_0x1b(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RR(temp_byte);
	LD16(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,RR (IY+$)*/
static void op_FDCB_0x1c(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RR(temp_byte);
	LD16(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,RR (IY+$)*/
static void op_FDCB_0x1d(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RR(temp_byte);
	LD16(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*RR (IY+$)*/
static void op_FDCB_0x1e(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RR(temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,RR (IY+$)*/
static void op_FDCB_0x1f(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RR(temp_byte);
	LD16(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,SLA (IY+$)*/
static void op_FDCB_0x20(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLA(temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,SLA (IY+$)*/
static void op_FDCB_0x21(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLA(temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,SLA (IY+$)*/
static void op_FDCB_0x22(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLA(temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,SLA (IY+$)*/
static void op_FDCB_0x23(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLA(temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,SLA (IY+$)*/
static void op_FDCB_0x24(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLA(temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,SLA (IY+$)*/
static void op_FDCB_0x25(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLA(temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*SLA (IY+$)*/
static void op_FDCB_0x26(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLA(temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,SLA (IY+$)*/
static void op_FDCB_0x27(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLA(temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,SRA (IY+$)*/
static void op_FDCB_0x28(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRA(temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,SRA (IY+$)*/
static void op_FDCB_0x29(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRA(temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,SRA (IY+$)*/
static void op_FDCB_0x2a(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRA(temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,SRA (IY+$)*/
static void op_FDCB_0x2b(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRA(temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,SRA (IY+$)*/
static void op_FDCB_0x2c(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRA(temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,SRA (IY+$)*/
static void op_FDCB_0x2d(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRA(temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*SRA (IY+$)*/
static void op_FDCB_0x2e(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRA(temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,SRA (IY+$)*/
static void op_FDCB_0x2f(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRA(temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,SLL (IY+$)*/
static void op_FDCB_0x30(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLL(temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,SLL (IY+$)*/
static void op_FDCB_0x31(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLL(temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,SLL (IY+$)*/
static void op_FDCB_0x32(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLL(temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,SLL (IY+$)*/
static void op_FDCB_0x33(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLL(temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,SLL (IY+$)*/
static void op_FDCB_0x34(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLL(temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,SLL (IY+$)*/
static void op_FDCB_0x35(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLL(temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*SLL (IY+$)*/
static void op_FDCB_0x36(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLL(temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,SLL (IY+$)*/
static void op_FDCB_0x37(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SLL(temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,SRL (IY+$)*/
static void op_FDCB_0x38(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRL(temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,SRL (IY+$)*/
static void op_FDCB_0x39(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRL(temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,SRL (IY+$)*/
static void op_FDCB_0x3a(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRL(temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,SRL (IY+$)*/
static void op_FDCB_0x3b(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRL(temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,SRL (IY+$)*/
static void op_FDCB_0x3c(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRL(temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,SRL (IY+$)*/
static void op_FDCB_0x3d(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRL(temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*SRL (IY+$)*/
static void op_FDCB_0x3e(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRL(temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,SRL (IY+$)*/
static void op_FDCB_0x3f(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SRL(temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*BIT 0,(IY+$)*/
static void op_FDCB_0x47(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	BIT_MPTR(0,temp_byte);
	T_WAIT_UNTIL(16);
	return;
}

/*BIT 1,(IY+$)*/
static void op_FDCB_0x4f(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	BIT_MPTR(1,temp_byte);
	T_WAIT_UNTIL(16);
	return;
}

/*BIT 2,(IY+$)*/
static void op_FDCB_0x57(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	BIT_MPTR(2,temp_byte);
	T_WAIT_UNTIL(16);
	return;
}

/*BIT 3,(IY+$)*/
static void op_FDCB_0x5f(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	BIT_MPTR(3,temp_byte);
	T_WAIT_UNTIL(16);
	return;
}

/*BIT 4,(IY+$)*/
static void op_FDCB_0x67(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	BIT_MPTR(4,temp_byte);
	T_WAIT_UNTIL(16);
	return;
}

/*BIT 5,(IY+$)*/
static void op_FDCB_0x6f(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	BIT_MPTR(5,temp_byte);
	T_WAIT_UNTIL(16);
	return;
}

/*BIT 6,(IY+$)*/
static void op_FDCB_0x77(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	BIT_MPTR(6,temp_byte);
	T_WAIT_UNTIL(16);
	return;
}

/*BIT 7,(IY+$)*/
static void op_FDCB_0x7f(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	BIT_MPTR(7,temp_byte);
	T_WAIT_UNTIL(16);
	return;
}

/*LD B,RES 0,(IY+$)*/
static void op_FDCB_0x80(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(0,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,RES 0,(IY+$)*/
static void op_FDCB_0x81(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(0,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,RES 0,(IY+$)*/
static void op_FDCB_0x82(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(0,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,RES 0,(IY+$)*/
static void op_FDCB_0x83(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(0,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,RES 0,(IY+$)*/
static void op_FDCB_0x84(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(0,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,RES 0,(IY+$)*/
static void op_FDCB_0x85(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(0,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*RES 0,(IY+$)*/
static void op_FDCB_0x86(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(0,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,RES 0,(IY+$)*/
static void op_FDCB_0x87(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(0,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,RES 1,(IY+$)*/
static void op_FDCB_0x88(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(1,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,RES 1,(IY+$)*/
static void op_FDCB_0x89(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(1,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,RES 1,(IY+$)*/
static void op_FDCB_0x8a(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(1,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,RES 1,(IY+$)*/
static void op_FDCB_0x8b(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(1,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,RES 1,(IY+$)*/
static void op_FDCB_0x8c(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(1,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,RES 1,(IY+$)*/
static void op_FDCB_0x8d(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(1,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*RES 1,(IY+$)*/
static void op_FDCB_0x8e(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(1,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,RES 1,(IY+$)*/
static void op_FDCB_0x8f(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(1,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,RES 2,(IY+$)*/
static void op_FDCB_0x90(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(2,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,RES 2,(IY+$)*/
static void op_FDCB_0x91(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(2,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,RES 2,(IY+$)*/
static void op_FDCB_0x92(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(2,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,RES 2,(IY+$)*/
static void op_FDCB_0x93(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(2,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,RES 2,(IY+$)*/
static void op_FDCB_0x94(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(2,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,RES 2,(IY+$)*/
static void op_FDCB_0x95(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(2,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*RES 2,(IY+$)*/
static void op_FDCB_0x96(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(2,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,RES 2,(IY+$)*/
static void op_FDCB_0x97(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(2,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,RES 3,(IY+$)*/
static void op_FDCB_0x98(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(3,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,RES 3,(IY+$)*/
static void op_FDCB_0x99(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(3,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,RES 3,(IY+$)*/
static void op_FDCB_0x9a(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(3,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,RES 3,(IY+$)*/
static void op_FDCB_0x9b(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(3,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,RES 3,(IY+$)*/
static void op_FDCB_0x9c(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(3,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,RES 3,(IY+$)*/
static void op_FDCB_0x9d(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(3,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*RES 3,(IY+$)*/
static void op_FDCB_0x9e(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(3,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,RES 3,(IY+$)*/
static void op_FDCB_0x9f(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(3,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,RES 4,(IY+$)*/
static void op_FDCB_0xa0(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(4,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,RES 4,(IY+$)*/
static void op_FDCB_0xa1(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(4,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,RES 4,(IY+$)*/
static void op_FDCB_0xa2(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(4,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,RES 4,(IY+$)*/
static void op_FDCB_0xa3(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(4,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,RES 4,(IY+$)*/
static void op_FDCB_0xa4(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(4,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,RES 4,(IY+$)*/
static void op_FDCB_0xa5(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(4,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*RES 4,(IY+$)*/
static void op_FDCB_0xa6(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(4,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,RES 4,(IY+$)*/
static void op_FDCB_0xa7(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(4,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,RES 5,(IY+$)*/
static void op_FDCB_0xa8(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(5,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,RES 5,(IY+$)*/
static void op_FDCB_0xa9(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(5,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,RES 5,(IY+$)*/
static void op_FDCB_0xaa(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(5,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,RES 5,(IY+$)*/
static void op_FDCB_0xab(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(5,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,RES 5,(IY+$)*/
static void op_FDCB_0xac(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(5,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,RES 5,(IY+$)*/
static void op_FDCB_0xad(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(5,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*RES 5,(IY+$)*/
static void op_FDCB_0xae(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(5,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,RES 5,(IY+$)*/
static void op_FDCB_0xaf(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(5,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,RES 6,(IY+$)*/
static void op_FDCB_0xb0(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(6,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,RES 6,(IY+$)*/
static void op_FDCB_0xb1(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(6,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,RES 6,(IY+$)*/
static void op_FDCB_0xb2(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(6,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,RES 6,(IY+$)*/
static void op_FDCB_0xb3(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(6,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,RES 6,(IY+$)*/
static void op_FDCB_0xb4(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(6,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,RES 6,(IY+$)*/
static void op_FDCB_0xb5(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(6,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*RES 6,(IY+$)*/
static void op_FDCB_0xb6(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(6,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,RES 6,(IY+$)*/
static void op_FDCB_0xb7(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(6,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,RES 7,(IY+$)*/
static void op_FDCB_0xb8(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(7,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,RES 7,(IY+$)*/
static void op_FDCB_0xb9(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(7,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,RES 7,(IY+$)*/
static void op_FDCB_0xba(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(7,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,RES 7,(IY+$)*/
static void op_FDCB_0xbb(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(7,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,RES 7,(IY+$)*/
static void op_FDCB_0xbc(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(7,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,RES 7,(IY+$)*/
static void op_FDCB_0xbd(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(7,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*RES 7,(IY+$)*/
static void op_FDCB_0xbe(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(7,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,RES 7,(IY+$)*/
static void op_FDCB_0xbf(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	RES(7,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,SET 0,(IY+$)*/
static void op_FDCB_0xc0(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(0,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,SET 0,(IY+$)*/
static void op_FDCB_0xc1(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(0,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,SET 0,(IY+$)*/
static void op_FDCB_0xc2(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(0,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,SET 0,(IY+$)*/
static void op_FDCB_0xc3(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(0,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,SET 0,(IY+$)*/
static void op_FDCB_0xc4(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(0,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,SET 0,(IY+$)*/
static void op_FDCB_0xc5(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(0,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*SET 0,(IY+$)*/
static void op_FDCB_0xc6(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(0,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,SET 0,(IY+$)*/
static void op_FDCB_0xc7(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(0,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,SET 1,(IY+$)*/
static void op_FDCB_0xc8(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(1,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,SET 1,(IY+$)*/
static void op_FDCB_0xc9(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(1,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,SET 1,(IY+$)*/
static void op_FDCB_0xca(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(1,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,SET 1,(IY+$)*/
static void op_FDCB_0xcb(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(1,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,SET 1,(IY+$)*/
static void op_FDCB_0xcc(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(1,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,SET 1,(IY+$)*/
static void op_FDCB_0xcd(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(1,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*SET 1,(IY+$)*/
static void op_FDCB_0xce(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(1,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,SET 1,(IY+$)*/
static void op_FDCB_0xcf(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(1,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,SET 2,(IY+$)*/
static void op_FDCB_0xd0(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(2,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,SET 2,(IY+$)*/
static void op_FDCB_0xd1(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(2,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,SET 2,(IY+$)*/
static void op_FDCB_0xd2(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(2,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,SET 2,(IY+$)*/
static void op_FDCB_0xd3(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(2,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,SET 2,(IY+$)*/
static void op_FDCB_0xd4(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(2,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,SET 2,(IY+$)*/
static void op_FDCB_0xd5(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(2,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*SET 2,(IY+$)*/
static void op_FDCB_0xd6(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(2,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,SET 2,(IY+$)*/
static void op_FDCB_0xd7(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(2,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,SET 3,(IY+$)*/
static void op_FDCB_0xd8(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(3,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,SET 3,(IY+$)*/
static void op_FDCB_0xd9(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(3,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,SET 3,(IY+$)*/
static void op_FDCB_0xda(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(3,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,SET 3,(IY+$)*/
static void op_FDCB_0xdb(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(3,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,SET 3,(IY+$)*/
static void op_FDCB_0xdc(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(3,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,SET 3,(IY+$)*/
static void op_FDCB_0xdd(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(3,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*SET 3,(IY+$)*/
static void op_FDCB_0xde(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(3,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,SET 3,(IY+$)*/
static void op_FDCB_0xdf(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(3,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,SET 4,(IY+$)*/
static void op_FDCB_0xe0(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(4,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,SET 4,(IY+$)*/
static void op_FDCB_0xe1(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(4,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,SET 4,(IY+$)*/
static void op_FDCB_0xe2(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(4,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,SET 4,(IY+$)*/
static void op_FDCB_0xe3(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(4,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,SET 4,(IY+$)*/
static void op_FDCB_0xe4(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(4,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,SET 4,(IY+$)*/
static void op_FDCB_0xe5(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(4,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*SET 4,(IY+$)*/
static void op_FDCB_0xe6(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(4,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,SET 4,(IY+$)*/
static void op_FDCB_0xe7(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(4,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,SET 5,(IY+$)*/
static void op_FDCB_0xe8(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(5,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,SET 5,(IY+$)*/
static void op_FDCB_0xe9(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(5,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,SET 5,(IY+$)*/
static void op_FDCB_0xea(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(5,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,SET 5,(IY+$)*/
static void op_FDCB_0xeb(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(5,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,SET 5,(IY+$)*/
static void op_FDCB_0xec(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(5,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,SET 5,(IY+$)*/
static void op_FDCB_0xed(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(5,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*SET 5,(IY+$)*/
static void op_FDCB_0xee(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(5,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,SET 5,(IY+$)*/
static void op_FDCB_0xef(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(5,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,SET 6,(IY+$)*/
static void op_FDCB_0xf0(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(6,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,SET 6,(IY+$)*/
static void op_FDCB_0xf1(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(6,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,SET 6,(IY+$)*/
static void op_FDCB_0xf2(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(6,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,SET 6,(IY+$)*/
static void op_FDCB_0xf3(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(6,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,SET 6,(IY+$)*/
static void op_FDCB_0xf4(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(6,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,SET 6,(IY+$)*/
static void op_FDCB_0xf5(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(6,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*SET 6,(IY+$)*/
static void op_FDCB_0xf6(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(6,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,SET 6,(IY+$)*/
static void op_FDCB_0xf7(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(6,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD B,SET 7,(IY+$)*/
static void op_FDCB_0xf8(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(7,temp_byte);
	LD(B,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD C,SET 7,(IY+$)*/
static void op_FDCB_0xf9(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(7,temp_byte);
	LD(C,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD D,SET 7,(IY+$)*/
static void op_FDCB_0xfa(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(7,temp_byte);
	LD(D,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD E,SET 7,(IY+$)*/
static void op_FDCB_0xfb(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(7,temp_byte);
	LD(E,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD H,SET 7,(IY+$)*/
static void op_FDCB_0xfc(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(7,temp_byte);
	LD(H,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD L,SET 7,(IY+$)*/
static void op_FDCB_0xfd(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(7,temp_byte);
	LD(L,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*SET 7,(IY+$)*/
static void op_FDCB_0xfe(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(7,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}

/*LD A,SET 7,(IY+$)*/
static void op_FDCB_0xff(Z80EX_CONTEXT *cpu)
{
	MEMPTR=(IY+temp_byte_s);
	READ_MEM(temp_byte,(IY+temp_byte_s),12);
	SET(7,temp_byte);
	LD(A,temp_byte);
	WRITE_MEM((IY+temp_byte_s),temp_byte,16);
	T_WAIT_UNTIL(19);
	return;
}



/**/
static const z80ex_opcode_fn opcodes_fdcb[0x100] = {
 op_FDCB_0x00  , op_FDCB_0x01  , op_FDCB_0x02  , op_FDCB_0x03  ,
 op_FDCB_0x04  , op_FDCB_0x05  , op_FDCB_0x06  , op_FDCB_0x07  ,
 op_FDCB_0x08  , op_FDCB_0x09  , op_FDCB_0x0a  , op_FDCB_0x0b  ,
 op_FDCB_0x0c  , op_FDCB_0x0d  , op_FDCB_0x0e  , op_FDCB_0x0f  ,
 op_FDCB_0x10  , op_FDCB_0x11  , op_FDCB_0x12  , op_FDCB_0x13  ,
 op_FDCB_0x14  , op_FDCB_0x15  , op_FDCB_0x16  , op_FDCB_0x17  ,
 op_FDCB_0x18  , op_FDCB_0x19  , op_FDCB_0x1a  , op_FDCB_0x1b  ,
 op_FDCB_0x1c  , op_FDCB_0x1d  , op_FDCB_0x1e  , op_FDCB_0x1f  ,
 op_FDCB_0x20  , op_FDCB_0x21  , op_FDCB_0x22  , op_FDCB_0x23  ,
 op_FDCB_0x24  , op_FDCB_0x25  , op_FDCB_0x26  , op_FDCB_0x27  ,
 op_FDCB_0x28  , op_FDCB_0x29  , op_FDCB_0x2a  , op_FDCB_0x2b  ,
 op_FDCB_0x2c  , op_FDCB_0x2d  , op_FDCB_0x2e  , op_FDCB_0x2f  ,
 op_FDCB_0x30  , op_FDCB_0x31  , op_FDCB_0x32  , op_FDCB_0x33  ,
 op_FDCB_0x34  , op_FDCB_0x35  , op_FDCB_0x36  , op_FDCB_0x37  ,
 op_FDCB_0x38  , op_FDCB_0x39  , op_FDCB_0x3a  , op_FDCB_0x3b  ,
 op_FDCB_0x3c  , op_FDCB_0x3d  , op_FDCB_0x3e  , op_FDCB_0x3f  ,
 op_FDCB_0x47  , op_FDCB_0x47  , op_FDCB_0x47  , op_FDCB_0x47  ,
 op_FDCB_0x47  , op_FDCB_0x47  , op_FDCB_0x47  , op_FDCB_0x47  ,
 op_FDCB_0x4f  , op_FDCB_0x4f  , op_FDCB_0x4f  , op_FDCB_0x4f  ,
 op_FDCB_0x4f  , op_FDCB_0x4f  , op_FDCB_0x4f  , op_FDCB_0x4f  ,
 op_FDCB_0x57  , op_FDCB_0x57  , op_FDCB_0x57  , op_FDCB_0x57  ,
 op_FDCB_0x57  , op_FDCB_0x57  , op_FDCB_0x57  , op_FDCB_0x57  ,
 op_FDCB_0x5f  , op_FDCB_0x5f  , op_FDCB_0x5f  , op_FDCB_0x5f  ,
 op_FDCB_0x5f  , op_FDCB_0x5f  , op_FDCB_0x5f  , op_FDCB_0x5f  ,
 op_FDCB_0x67  , op_FDCB_0x67  , op_FDCB_0x67  , op_FDCB_0x67  ,
 op_FDCB_0x67  , op_FDCB_0x67  , op_FDCB_0x67  , op_FDCB_0x67  ,
 op_FDCB_0x6f  , op_FDCB_0x6f  , op_FDCB_0x6f  , op_FDCB_0x6f  ,
 op_FDCB_0x6f  , op_FDCB_0x6f  , op_FDCB_0x6f  , op_FDCB_0x6f  ,
 op_FDCB_0x77  , op_FDCB_0x77  , op_FDCB_0x77  , op_FDCB_0x77  ,
 op_FDCB_0x77  , op_FDCB_0x77  , op_FDCB_0x77  , op_FDCB_0x77  ,
 op_FDCB_0x7f  , op_FDCB_0x7f  , op_FDCB_0x7f  , op_FDCB_0x7f  ,
 op_FDCB_0x7f  , op_FDCB_0x7f  , op_FDCB_0x7f  , op_FDCB_0x7f  ,
 op_FDCB_0x80  , op_FDCB_0x81  , op_FDCB_0x82  , op_FDCB_0x83  ,
 op_FDCB_0x84  , op_FDCB_0x85  , op_FDCB_0x86  , op_FDCB_0x87  ,
 op_FDCB_0x88  , op_FDCB_0x89  , op_FDCB_0x8a  , op_FDCB_0x8b  ,
 op_FDCB_0x8c  , op_FDCB_0x8d  , op_FDCB_0x8e  , op_FDCB_0x8f  ,
 op_FDCB_0x90  , op_FDCB_0x91  , op_FDCB_0x92  , op_FDCB_0x93  ,
 op_FDCB_0x94  , op_FDCB_0x95  , op_FDCB_0x96  , op_FDCB_0x97  ,
 op_FDCB_0x98  , op_FDCB_0x99  , op_FDCB_0x9a  , op_FDCB_0x9b  ,
 op_FDCB_0x9c  , op_FDCB_0x9d  , op_FDCB_0x9e  , op_FDCB_0x9f  ,
 op_FDCB_0xa0  , op_FDCB_0xa1  , op_FDCB_0xa2  , op_FDCB_0xa3  ,
 op_FDCB_0xa4  , op_FDCB_0xa5  , op_FDCB_0xa6  , op_FDCB_0xa7  ,
 op_FDCB_0xa8  , op_FDCB_0xa9  , op_FDCB_0xaa  , op_FDCB_0xab  ,
 op_FDCB_0xac  , op_FDCB_0xad  , op_FDCB_0xae  , op_FDCB_0xaf  ,
 op_FDCB_0xb0  , op_FDCB_0xb1  , op_FDCB_0xb2  , op_FDCB_0xb3  ,
 op_FDCB_0xb4  , op_FDCB_0xb5  , op_FDCB_0xb6  , op_FDCB_0xb7  ,
 op_FDCB_0xb8  , op_FDCB_0xb9  , op_FDCB_0xba  , op_FDCB_0xbb  ,
 op_FDCB_0xbc  , op_FDCB_0xbd  , op_FDCB_0xbe  , op_FDCB_0xbf  ,
 op_FDCB_0xc0  , op_FDCB_0xc1  , op_FDCB_0xc2  , op_FDCB_0xc3  ,
 op_FDCB_0xc4  , op_FDCB_0xc5  , op_FDCB_0xc6  , op_FDCB_0xc7  ,
 op_FDCB_0xc8  , op_FDCB_0xc9  , op_FDCB_0xca  , op_FDCB_0xcb  ,
 op_FDCB_0xcc  , op_FDCB_0xcd  , op_FDCB_0xce  , op_FDCB_0xcf  ,
 op_FDCB_0xd0  , op_FDCB_0xd1  , op_FDCB_0xd2  , op_FDCB_0xd3  ,
 op_FDCB_0xd4  , op_FDCB_0xd5  , op_FDCB_0xd6  , op_FDCB_0xd7  ,
 op_FDCB_0xd8  , op_FDCB_0xd9  , op_FDCB_0xda  , op_FDCB_0xdb  ,
 op_FDCB_0xdc  , op_FDCB_0xdd  , op_FDCB_0xde  , op_FDCB_0xdf  ,
 op_FDCB_0xe0  , op_FDCB_0xe1  , op_FDCB_0xe2  , op_FDCB_0xe3  ,
 op_FDCB_0xe4  , op_FDCB_0xe5  , op_FDCB_0xe6  , op_FDCB_0xe7  ,
 op_FDCB_0xe8  , op_FDCB_0xe9  , op_FDCB_0xea  , op_FDCB_0xeb  ,
 op_FDCB_0xec  , op_FDCB_0xed  , op_FDCB_0xee  , op_FDCB_0xef  ,
 op_FDCB_0xf0  , op_FDCB_0xf1  , op_FDCB_0xf2  , op_FDCB_0xf3  ,
 op_FDCB_0xf4  , op_FDCB_0xf5  , op_FDCB_0xf6  , op_FDCB_0xf7  ,
 op_FDCB_0xf8  , op_FDCB_0xf9  , op_FDCB_0xfa  , op_FDCB_0xfb  ,
 op_FDCB_0xfc  , op_FDCB_0xfd  , op_FDCB_0xfe  , op_FDCB_0xff  
};
